@@ -89,12 +89,12 @@ VIDEO_FILTER = {
 }
 
 
-class VideoRefField(FileRefField):
+class VideoFileRefField(FileRefField):
     """A foreign key to a File, constrained to only select video files."""
 
     def __init__(self, **kwargs):
         kwargs["limit_choices_to"] = VIDEO_FILTER
-        super(VideoRefField, self).__init__(**kwargs)
+        super(VideoFileRefField, self).__init__(**kwargs)
 
 
 class Video(models.Model):
@@ -108,19 +108,19 @@ class Video(models.Model):
         null=True,
     )
 
-    high_resolution_mp4 = VideoRefField(
+    high_resolution_mp4 = VideoFileRefField(
         verbose_name="high resolution MP4",
         blank=True,
         null=True,
     )
 
-    low_resolution_mp4 = VideoRefField(
+    low_resolution_mp4 = VideoFileRefField(
         verbose_name="low resolution MP4",
         blank=True,
         null=True
     )
 
-    webm = VideoRefField(
+    webm = VideoFileRefField(
         verbose_name="WebM",
         blank=True,
         null=True,
@@ -132,3 +132,20 @@ class Video(models.Model):
 
     class Meta:
         ordering = ("title",)
+
+
+class VideoRefField(models.ForeignKey):
+
+    """A foreign key to a File, constrained to only select image files."""
+
+    def __init__(self, **kwargs):
+        kwargs["to"] = Video
+        kwargs.setdefault("related_name", "+")
+        kwargs.setdefault("on_delete", models.PROTECT)
+        super(VideoRefField, self).__init__(**kwargs)
+
+    def formfield(self, **kwargs):
+        defaults = {
+            "widget": ForeignKeyRawIdWidget(self.rel, admin.site),
+        }
+        return super(VideoRefField, self).formfield(**defaults)
